export interface IUser {
    userId: string;
    roles: string[];
    name?: string;
    phone?: string;
    email?: string;
    extra?: IExtra;
}
export declare enum EOrderType {
    TAKE_AWAY = 0,
    DELIVERY = 1,
    DINE_IN = 2,
    DINE_IN_OPEN = 3
}
export declare enum EOrderStatus {
    NEW = 0,
    COMPLETED = 1,
    DELIVER = 2
}
export declare enum EOrderPaymentType {
    CASH = 0,
    COD = 1,
    EPAYMENT = 2
}
export interface IOrder {
    id: string;
    tenant: string;
    created: Date;
    lastChanged?: Date;
    completedTime?: Date;
    closedDate?: Date;
    processingStartedTime?: Date;
    deliveredTime?: Date;
    due?: Date;
    deliveryAddress?: IOrderDeliveryAddress;
    geoPosition?: {
        lat: number;
        lng: number;
    };
    source?: string;
    users?: IUser;
    orderType: EOrderType;
    total?: number;
    editTotal?: number;
    status: EOrderStatus;
    statusInfo?: string;
    closed?: boolean;
    completed?: boolean;
    claimCode?: string;
    buckets: IOrderInBucket[];
    loyaltyId?: string;
    coupons?: IOrderCoupon[];
    payments?: IOrderPayment[];
    comments?: IOrderComment[];
}
export interface IOrderInBucket {
    venue: string;
    name: string;
    menu: string;
    lines: IOrderLine[];
    priceList?: string;
    warehouse?: string;
    queuePos?: number;
    extra?: IExtra;
}
export interface IOrderLine {
    id: string;
    creator: string;
    created: Date;
    updated: Date;
    source: string;
    quantity: number;
    price: number;
    productId: string;
    product: IOrderProduct;
    extra: IExtra;
}
export interface IOrderProduct {
    id: string;
    kind: string;
    literals: IProductLiterals;
    items: IOrderProduct[];
    img: string;
    quantity: number;
    price: number;
    extra: IExtra;
}
export interface IProductLiterals {
    [propName: string]: any;
}
export interface IExtra {
    [propName: string]: any;
}
export interface IOrderCoupon {
    coupon: string;
}
export interface IOrderPayment {
    id: string;
    type: EOrderPaymentType;
    source: string;
    amount: number;
    initialAmount: number;
    user: string;
    timestamp: Date;
    extra: IExtra;
}
export interface IOrderComment {
    id: string;
    creator: string;
    timestamp: Date;
    comment: string;
    extra?: IExtra;
}
export interface IOrderDeliveryAddress {
    street: string;
    number: string;
    door: string;
    postal: string;
    city: string;
    country: string;
}
export declare enum EOrderRecStatus {
    INITIALIZING = 0,
    INVALID = 1,
    VALID = 2
}
export interface IOrderRec {
    order?: IOrder;
    createOrderCorrelationId: string;
    recStatus: EOrderRecStatus;
}
export interface IRefreshTokenHandler {
    getRefreshToken(): string;
    setRefreshToken(refreshToken: string): void;
}
export interface IAuthDataProvider {
    (ctx: any, getRefreshToken: IRefreshTokenHandler, forceRefresh?: boolean): Promise<{
        token: string;
        UUID: string;
    }>;
}
export interface IOrderServerTool {
    createOrder(ctx: any, tokenProvider: IAuthDataProvider): Promise<{
        id: string;
        correlationId: string;
    }>;
    fetchOrder(ctx: any, id: string, tokenProvider: IAuthDataProvider): IOrder;
}
